@@ -182,26 +182,30 @@ class FigureStream(Figure):
     # ----------------------------------------------------------------------
     def _video_feed(self):
         """"""
+        self.proccess_interact(request.values)
+
         if self.size == 'auto':
             width = request.values.get('width', None)
             height = request.values.get('height', None)
             if (
-                width and
-                height and
-                width.replace('.', '').isdigit() and
-                height.replace('.', '').isdigit()
+                width
+                and height
+                and width.replace('.', '').isdigit()
+                and height.replace('.', '').isdigit()
             ):
                 self.set_size_inches(float(width), float(height))
 
-            dpi = request.values.get('dpi', None)
-            if dpi and dpi.replace('.', '').isdigit():
-                self.set_dpi(float(dpi))
+            # dpi = request.values.get('dpi', None)
+            # if dpi and dpi.replace('.', '').isdigit():
+                # self.set_dpi(float(dpi))
 
         else:
             self.set_size_inches(*self.size)
-            dpi = request.values.get('dpi', None)
-            if dpi and dpi.replace('.', '').isdigit():
-                self.set_dpi(float(dpi))
+            # dpi = request.values.get('dpi', None)
+            # if dpi and dpi.replace('.', '').isdigit():
+                # self.set_dpi(float(dpi))
+
+        # self.proccess_interact(request.values)
 
         if self.__class_attr['thread'] is None:
             self.__class_attr['last_access'] = time.time()
@@ -215,7 +219,6 @@ class FigureStream(Figure):
             while self._get_frames() is None:
                 time.sleep(0.1)
 
-        # self.feed()
         return Response(
             self._get_frames(),
             mimetype='multipart/x-mixed-replace; boundary=frame',
@@ -229,7 +232,6 @@ class FigureStream(Figure):
         self.canvas.print_figure(
             self.__output, format='jpeg', dpi=self.get_dpi()
         )
-
         return self.__buffer.put(self.__output.getvalue())
 
     # # ----------------------------------------------------------------------
@@ -237,3 +239,17 @@ class FigureStream(Figure):
         # """"""
         # self.feed()
 
+    # ----------------------------------------------------------------------
+    def interact_dpi(self, dpi):
+        """"""
+        if dpi and dpi.replace('.', '').isdigit():
+            self.set_dpi(float(dpi))
+
+    # ----------------------------------------------------------------------
+    def proccess_interact(self, values):
+        """"""
+        for key in values:
+            if key in ['width', 'height', 'background']:
+                continue
+            if interact := getattr(self, f'interact_{key.lower().replace(" ","_")}', False):
+                interact(values.get(key))
